"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDatabaseSchemas = exports.getCollectionSchema = exports.mongodb = void 0;
const mongodb_1 = require("mongodb");
function mongodb(serverUri, dbName) {
    return __awaiter(this, void 0, void 0, function* () {
        const client = new mongodb_1.MongoClient(serverUri, {
            useNewUrlParser: true,
            useUnifiedTopology: true,
        });
        yield client.connect();
        const db = client.db(dbName);
        return { client, db };
    });
}
exports.mongodb = mongodb;
/**
 * Retrieves the stored JSON Schema from a MongoDB collection
 */
function getCollectionSchema(col) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const options = (yield col.options());
        return (_a = options.validator) === null || _a === void 0 ? void 0 : _a.$jsonSchema;
    });
}
exports.getCollectionSchema = getCollectionSchema;
/**
 * Retrieves a list of JSON Schemas for each collection of the MongoDB server
 */
function getDatabaseSchemas(serverUri, dbName) {
    return __awaiter(this, void 0, void 0, function* () {
        const { client, db } = yield mongodb(serverUri, dbName);
        const allCols = yield db.collections();
        const r = yield Promise.all(allCols.map((col) => __awaiter(this, void 0, void 0, function* () {
            return {
                collectionName: col.collectionName,
                schema: yield getCollectionSchema(col),
            };
        })));
        yield client.close();
        return r;
    });
}
exports.getDatabaseSchemas = getDatabaseSchemas;
//# sourceMappingURL=mongodb.js.map