"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.expandEnv = exports.loadConfig = exports.parseConfig = exports.defaultOptions = exports.prettierOptions = void 0;
const fs_1 = __importDefault(require("fs"));
const prettier_1 = __importDefault(require("prettier"));
function prettierOptions(path) {
    return __awaiter(this, void 0, void 0, function* () {
        const options = yield prettier_1.default.resolveConfig(path);
        return Object.assign(Object.assign({}, options), { parser: "typescript" });
    });
}
exports.prettierOptions = prettierOptions;
exports.defaultOptions = {
    uri: "mongodb://localhost:27017",
    database: "",
    out: "src/__generated__",
    bannerComment: [
        "/* eslint-disable */",
        "/* tslint:disable */",
        "",
        "/**",
        "* This file was automatically generated by bson-schema-to-typescript.",
        "* https://www.npmjs.com/package/bson-schema-to-typescript",
        "*",
        "* Do not modify it by hand. Instead, modify the MongoDB $jsonSchema validator,",
        "* and run bson2ts to regenerate this file.",
        "*/",
    ],
    enableConstEnums: true,
    ignoreMinAndMaxItems: false,
    strictIndexSignatures: false,
    unknownAny: true,
};
function readConfig() {
    const configPath = "./bson2ts.json";
    return fs_1.default.existsSync(configPath)
        ? fs_1.default.readFileSync(configPath).toString()
        : JSON.stringify({});
}
function parseConfig(config) {
    try {
        const options = JSON.parse(config);
        if (typeof options !== "object" ||
            options === null ||
            Array.isArray(options)) {
            throw new Error("config must be a plain object");
        }
        const uri = typeof options.uri === "string"
            ? expandEnv(options.uri)
            : exports.defaultOptions.uri;
        const database = typeof options.database === "string"
            ? expandEnv(options.database)
            : exports.defaultOptions.database;
        const out = typeof options.out === "string" ? options.out : exports.defaultOptions.out;
        const bannerComment = (Array.isArray(options.bannerComment) &&
            options.bannerComment.every((e) => typeof e === "string")
            ? options.bannerComment
            : exports.defaultOptions.bannerComment);
        const enableConstEnums = typeof options.enableConstEnums === "boolean"
            ? options.enableConstEnums
            : exports.defaultOptions.enableConstEnums;
        const ignoreMinAndMaxItems = typeof options.ignoreMinAndMaxItems === "boolean"
            ? options.ignoreMinAndMaxItems
            : exports.defaultOptions.ignoreMinAndMaxItems;
        const strictIndexSignatures = typeof options.strictIndexSignatures === "boolean"
            ? options.strictIndexSignatures
            : exports.defaultOptions.strictIndexSignatures;
        const unknownAny = typeof options.unknownAny === "boolean"
            ? options.unknownAny
            : exports.defaultOptions.unknownAny;
        return {
            uri,
            database,
            out,
            bannerComment,
            enableConstEnums,
            ignoreMinAndMaxItems,
            strictIndexSignatures,
            unknownAny,
        };
    }
    catch (error) {
        return exports.defaultOptions;
    }
}
exports.parseConfig = parseConfig;
function loadConfig() {
    const config = readConfig();
    return parseConfig(config);
}
exports.loadConfig = loadConfig;
function getEnv(name) {
    const env = process.env[name];
    if (!env) {
        throw new Error(`${name} environment variable not defined`);
    }
    return env;
}
/**
 * Returns the expanded environment variable if the provided value starts with
 * "$", otherwise returns the provided value as-is.
 */
function expandEnv(val) {
    return val.startsWith("$") ? getEnv(val.slice(1)) : val;
}
exports.expandEnv = expandEnv;
//# sourceMappingURL=options.js.map