"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const options_1 = require("./options");
describe("Default options", () => {
    /**
     * JSON.stringify generated inputs
     */
    // Null
    test("null returns default options", () => {
        const config = JSON.stringify(null);
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    // Undefined
    test("undefined returns default options", () => {
        const config = JSON.stringify(undefined);
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    // Boolean
    test("boolean returns default options", () => {
        const config = JSON.stringify(false);
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    test("boolean returns default options", () => {
        const config = JSON.stringify(true);
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    // Number
    test("number returns default options (JSON)", () => {
        const config = JSON.stringify(1);
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    test("number returns default options (JSON)", () => {
        const config = JSON.stringify(0);
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    test("number returns default options (JSON)", () => {
        const config = JSON.stringify(1.1);
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    // Object
    test("empty object returns default options", () => {
        const config = JSON.stringify({});
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    // Array
    test("empty array returns default options", () => {
        const config = JSON.stringify([]);
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    test("array returns default options", () => {
        const config = JSON.stringify(["1"]);
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    // String
    test("empty string returns default options", () => {
        const config = JSON.stringify("");
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    test("some string returns default options", () => {
        const config = JSON.stringify("x");
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    /**
     * Plain string inputs
     */
    test("empty string returns default options", () => {
        const config = "";
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    test("some string returns default options", () => {
        const config = "x";
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    test("some string returns default options", () => {
        const config = "undefined";
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
});
describe("Modified options with wrong type", () => {
    // out
    test("out as number returns default options", () => {
        const config = JSON.stringify({ out: 1 });
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    // bannerComment
    test("bannerComment as boolean returns default options", () => {
        const config = JSON.stringify({ bannerComment: true });
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    test("bannerComment as array of non-strings returns default options", () => {
        const config = JSON.stringify({ bannerComment: [false] });
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    // enableConstEnums
    test("enableConstEnums as string returns default options", () => {
        const config = JSON.stringify({ enableConstEnums: "some string" });
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    // ignoreMinAndMaxItems
    test("ignoreMinAndMaxItems as object returns default options", () => {
        const config = JSON.stringify({ ignoreMinAndMaxItems: { x: 1 } });
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    // strictIndexSignatures
    test("strictIndexSignatures as null returns default options", () => {
        const config = JSON.stringify({ strictIndexSignatures: null });
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    // unknownAny
    test("unknownAny as array returns default options", () => {
        const config = JSON.stringify({ unknownAny: ["1"] });
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
});
describe("Modified options", () => {
    // uri
    test("uri - string", () => {
        const config = JSON.stringify({ uri: "connection-string" });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { uri: "connection-string" }));
    });
    test("uri - environment variable", () => {
        process.env.MONGO_URI = "connection-string";
        const config = JSON.stringify({ uri: "$MONGO_URI" });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { uri: "connection-string" }));
        delete process.env.MONGO_URI;
    });
    // database
    test("database - string", () => {
        const config = JSON.stringify({ database: "db-string" });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { database: "db-string" }));
    });
    test("database - environment variable", () => {
        process.env.MONGO_DB = "db-string";
        const config = JSON.stringify({ database: "$MONGO_DB" });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { database: "db-string" }));
        delete process.env.MONGO_DB;
    });
    // out
    test("out", () => {
        const config = JSON.stringify({ out: "newPath/" });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { out: "newPath/" }));
    });
    // bannerComment
    test("bannerComment", () => {
        const config = JSON.stringify({ bannerComment: ["some banner"] });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { bannerComment: ["some banner"] }));
    });
    // enableConstEnums
    test("enableConstEnums", () => {
        const config = JSON.stringify({ enableConstEnums: false });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { enableConstEnums: false }));
    });
    // ignoreMinAndMaxItems
    test("ignoreMinAndMaxItems", () => {
        const config = JSON.stringify({ ignoreMinAndMaxItems: true });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { ignoreMinAndMaxItems: true }));
    });
    // strictIndexSignatures
    test("strictIndexSignatures", () => {
        const config = JSON.stringify({ strictIndexSignatures: true });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { strictIndexSignatures: true }));
    });
    // unknownAny
    test("unknownAny", () => {
        const config = JSON.stringify({ unknownAny: false });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { unknownAny: false }));
    });
});
describe("Omit excess and invalid options", () => {
    test("excess option is skipped", () => {
        const config = JSON.stringify({ excessOption: false });
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    test("invalid option is skipped", () => {
        const config = JSON.stringify({ unknownAny: "should be boolean" });
        expect(options_1.parseConfig(config)).toStrictEqual(options_1.defaultOptions);
    });
    test("excess option is skipped and valid option is in effect", () => {
        const config = JSON.stringify({
            enableConstEnums: false,
            excessOption: false,
        });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { enableConstEnums: false }));
    });
    test("invalid option is skipped and valid option is in effect", () => {
        const config = JSON.stringify({
            enableConstEnums: false,
            unknownAny: "should be boolean",
        });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { enableConstEnums: false }));
    });
    test("excess option is skipped, invalid option is skipped, and valid option is in effect", () => {
        const config = JSON.stringify({
            enableConstEnums: false,
            excessOption: false,
            ignoreMinAndMaxItems: "xxx",
        });
        expect(options_1.parseConfig(config)).toStrictEqual(Object.assign(Object.assign({}, options_1.defaultOptions), { enableConstEnums: false }));
    });
});
describe("expandEnvironment", () => {
    test("String: SOME_VALUE", () => {
        expect(options_1.expandEnv("SOME_VALUE")).toBe("SOME_VALUE");
    });
    test("Env:    $SOME_DEFINED_VAR", () => {
        process.env.SOME_DEFINED_VAR = "SOME_VALUE";
        expect(options_1.expandEnv("$SOME_DEFINED_VAR")).toBe("SOME_VALUE");
        delete process.env.SOME_DEFINED_VAR;
    });
    test("Env:    $SOME_UNDEFINED_VAR", () => {
        expect(() => {
            options_1.expandEnv("$SOME_UNDEFINED_VAR");
        }).toThrow();
    });
});
//# sourceMappingURL=options.test.js.map